Class: Google::Api::MethodSettings

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/client.rb

Overview

Describes the generator configuration for a method.

Defined Under Namespace

Classes: LongRunning

Instance Attribute Summary collapse

Instance Attribute Details

#auto_populated_fields ⇒ ::Array<::String>



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'proto_docs/google/api/client.rb', line 412

class MethodSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes settings to use when generating API methods that use the
  # long-running operation pattern.
  # All default values below are from those used in the client library
  # generators (e.g.
  # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
  # @!attribute [rw] initial_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Initial delay after which the first poll request will be made.
  #     Default value: 5 seconds.
  # @!attribute [rw] poll_delay_multiplier
  #   @return [::Float]
  #     Multiplier to gradually increase delay between subsequent polls until it
  #     reaches max_poll_delay.
  #     Default value: 1.5.
  # @!attribute [rw] max_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Maximum time between two subsequent poll requests.
  #     Default value: 45 seconds.
  # @!attribute [rw] total_poll_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Total polling timeout.
  #     Default value: 5 minutes.
  class LongRunning
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#batching ⇒ ::Google::Api::BatchingConfigProto



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'proto_docs/google/api/client.rb', line 412

class MethodSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes settings to use when generating API methods that use the
  # long-running operation pattern.
  # All default values below are from those used in the client library
  # generators (e.g.
  # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
  # @!attribute [rw] initial_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Initial delay after which the first poll request will be made.
  #     Default value: 5 seconds.
  # @!attribute [rw] poll_delay_multiplier
  #   @return [::Float]
  #     Multiplier to gradually increase delay between subsequent polls until it
  #     reaches max_poll_delay.
  #     Default value: 1.5.
  # @!attribute [rw] max_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Maximum time between two subsequent poll requests.
  #     Default value: 45 seconds.
  # @!attribute [rw] total_poll_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Total polling timeout.
  #     Default value: 5 minutes.
  class LongRunning
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#long_running ⇒ ::Google::Api::MethodSettings::LongRunning



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'proto_docs/google/api/client.rb', line 412

class MethodSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes settings to use when generating API methods that use the
  # long-running operation pattern.
  # All default values below are from those used in the client library
  # generators (e.g.
  # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
  # @!attribute [rw] initial_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Initial delay after which the first poll request will be made.
  #     Default value: 5 seconds.
  # @!attribute [rw] poll_delay_multiplier
  #   @return [::Float]
  #     Multiplier to gradually increase delay between subsequent polls until it
  #     reaches max_poll_delay.
  #     Default value: 1.5.
  # @!attribute [rw] max_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Maximum time between two subsequent poll requests.
  #     Default value: 45 seconds.
  # @!attribute [rw] total_poll_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Total polling timeout.
  #     Default value: 5 minutes.
  class LongRunning
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#selector ⇒ ::String



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'proto_docs/google/api/client.rb', line 412

class MethodSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes settings to use when generating API methods that use the
  # long-running operation pattern.
  # All default values below are from those used in the client library
  # generators (e.g.
  # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
  # @!attribute [rw] initial_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Initial delay after which the first poll request will be made.
  #     Default value: 5 seconds.
  # @!attribute [rw] poll_delay_multiplier
  #   @return [::Float]
  #     Multiplier to gradually increase delay between subsequent polls until it
  #     reaches max_poll_delay.
  #     Default value: 1.5.
  # @!attribute [rw] max_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Maximum time between two subsequent poll requests.
  #     Default value: 45 seconds.
  # @!attribute [rw] total_poll_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Total polling timeout.
  #     Default value: 5 minutes.
  class LongRunning
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end