Class: Google::Cloud::Memcache::V1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/memcache/v1/cloud_memcache.rb

Overview

Response for ListInstances.

Instance Attribute Summary collapse

Instance Attribute Details

#instances ⇒ ::Array<::Google::Cloud::Memcache::V1::Instance>

Returns A list of Memcached instances in the project in the specified location, or across all locations.

If the location_id in the parent field of the request is "-", all regions available to the project are queried, and the results aggregated.

Returns:

  • (::Array<::Google::Cloud::Memcache::V1::Instance>) —

    A list of Memcached instances in the project in the specified location, or across all locations.

    If the location_id in the parent field of the request is "-", all regions available to the project are queried, and the results aggregated.



348
349
350
351
# File 'proto_docs/google/cloud/memcache/v1/cloud_memcache.rb', line 348

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token ⇒ ::String

Returns Token to retrieve the next page of results, or empty if there are no more results in the list.

Returns:

  • (::String) —

    Token to retrieve the next page of results, or empty if there are no more results in the list.



348
349
350
351
# File 'proto_docs/google/cloud/memcache/v1/cloud_memcache.rb', line 348

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable ⇒ ::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>) —

    Locations that could not be reached.



348
349
350
351
# File 'proto_docs/google/cloud/memcache/v1/cloud_memcache.rb', line 348

class ListInstancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end