Class: Google::Longrunning::ListOperationsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/longrunning/operations.rb

Overview

The request message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Attribute Details

#filter ⇒ ::String

Returns The standard list filter.

Returns:

  • (::String) —

    The standard list filter.



98
99
100
101
# File 'proto_docs/google/longrunning/operations.rb', line 98

class ListOperationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name ⇒ ::String

Returns The name of the operation's parent resource.

Returns:

  • (::String) —

    The name of the operation's parent resource.



98
99
100
101
# File 'proto_docs/google/longrunning/operations.rb', line 98

class ListOperationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size ⇒ ::Integer

Returns The standard list page size.

Returns:

  • (::Integer) —

    The standard list page size.



98
99
100
101
# File 'proto_docs/google/longrunning/operations.rb', line 98

class ListOperationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token ⇒ ::String

Returns The standard list page token.

Returns:

  • (::String) —

    The standard list page token.



98
99
100
101
# File 'proto_docs/google/longrunning/operations.rb', line 98

class ListOperationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#return_partial_success ⇒ ::Boolean

Returns When set to true, operations that are reachable are returned as normal, and those that are unreachable are returned in the [ListOperationsResponse.unreachable] field.

This can only be true when reading across collections e.g. when parent is set to "projects/example/locations/-".

This field is not by default supported and will result in an UNIMPLEMENTED error if set unless explicitly documented otherwise in service or product specific documentation.

Returns:

  • (::Boolean) —

    When set to true, operations that are reachable are returned as normal, and those that are unreachable are returned in the [ListOperationsResponse.unreachable] field.

    This can only be true when reading across collections e.g. when parent is set to "projects/example/locations/-".

    This field is not by default supported and will result in an UNIMPLEMENTED error if set unless explicitly documented otherwise in service or product specific documentation.



98
99
100
101
# File 'proto_docs/google/longrunning/operations.rb', line 98

class ListOperationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end